Crate welly_parser

source

Modules

  • Welly’s bracket matcher.
  • Welly’s expressions.
  • Welly’s lexer.
  • Re-exports all the Welly Parse implementations and [Brackets].
  • Welly’s imperative statements.
  • Re-exports all the Welly parse Tree types (except char) and Op.
  • Welly’s words, including keywords.

Structs

  • A growable source file that can be parsed incrementally.
  • A Stream through a str.
  • A high-level wrapper around an input Stream.
  • Represents the end of the source code.
  • A position in source code in a form that can be reported to the user. More precisely, a Location represents a contiguous range of bytes of source code.
  • Represents a parse Tree or a parse error, with a Location.

Traits

Functions