pub struct Loc<T>(/* private fields */);Expand description
Represents a T with a Location.
This is commonly used to represent bits of a parse tree, remembering where they came from in the source code.
Loc::unwrap(self) or *self unwraps the T. Loc::location(&self)
returns the Location.
Implementations