welly_parser

Struct Token

source
pub struct Token(pub Location, pub Result<Box<dyn Tree>, String>);
Represents a parse Tree or a parse error, with a Location.

  • Token(loc, Ok(t)) represents a parse-tree t. t can be EndOfFile to represent the end of the source code. In this case, the Location is spurious.
  • Token(loc, Err(e)) represents an error message e. e can be the empty string to mark the end of incomplete source code. In this case, the Location is spurious.

Tuple Fields

0: Location1: Result<Box<dyn Tree>, String>

Implementations

source

impl Token

source

pub fn end_of_file() -> Self

Returns an EndOfFile, to indicate the end of the source code.

source

pub fn incomplete() -> Self

Returns an empty error message, to indicate incomplete source code.

source

pub fn downcast_copy<T: Tree + Copy>(&self) -> Option<T>

If self is Token(_, Ok(t)) and t is of type T, return it.

source

pub fn is<T: Tree>(&self) -> bool

Tests whether self is a T.

source

pub fn is_incomplete(&self) -> bool

Tests whether self marks the end of incomplete source code.

source

pub fn unwrap<T: Tree>(self) -> T

Discard the Location, panic on Err, and panic if the payload is not of type T.

This is useful in test code.

source

pub fn unwrap_err(self) -> String

Discard the Location, panic on Ok, return the error message.

This is useful in test code.