welly_parser::welly

Type Alias AssignOp

source
pub type AssignOp = AssignOp;

Aliased Type

enum AssignOp {
    Let,
    Set,
    Op(Op),
}

Variants



Let

x = 1 declares the name x and initialises it to 1.



Set

x := 1 overwrites the value of the name x with 1.



Op(Op)

x += 1 is an abbreviation for x := x + 1.