welly_parser::wellyType Alias AssignOp
source pub type AssignOp = AssignOp;
enum AssignOp {
Let,
Set,
Op(Op),
}
x = 1 declares the name x and initialises it to 1.
x := 1 overwrites the value of the name x with 1.
x += 1 is an abbreviation for x := x + 1.